#
# K2HR3 Utilities - Command Line Interface
#
# Copyright 2021 Yahoo Japan Corporation.
#
# K2HR3 is K2hdkc based Resource and Roles and policy Rules, gathers
# common management information for the cloud.
# K2HR3 can dynamically manage information as "who", "what", "operate".
# These are stored as roles, resources, policies in K2hdkc, and the
# client system can dynamically read and modify these information.
#
# For the full copyright and license information, please view
# the license file that was distributed with this source code.
#
# AUTHOR:   Takeshi Nakatani
# CREATE:   Mon Feb 15 2021
# REVISION:
#

#
# Local macros/define
#
%if %{undefined package_revision}
%global package_revision 1
%endif

%if %{undefined make_build}
%global make_build %{__make} %{?_smp_mflags}
%endif

%if %{undefined autosetup}
%global autosetup %setup -q
%endif

%global gittag v1.0.12

%if %{undefined make_check}
%global make_check 1
%endif

%if %{undefined not_run_autogen}
%global run_autogen ./autogen.sh
%else
%global run_autogen echo "skip autogen.sh"
%endif

#
# main package
#
Summary: K2HR3 Command Line Interface.
Name: k2hr3-cli
Version: 1.0.12
Release: %{package_revision}%{?dist}
License: MIT
Group: Applications/Other
URL: https://github.com/yahoojapan/k2hr3-cli
Source0: https://github.com/yahoojapan/k2hr3-cli/archive/%{gittag}/%{name}-%{version}.tar.gz
BuildRequires: git-core make
BuildArch: noarch

%description
K2HR3(K2Hdkc based Resource and Roles and policy Rules) is one of
extended RBAC (Role Based Access Control) system.
K2HR3 works as RBAC in cooperation with OpenStack and Kubernetes which
are the IaaS(Infrastructure as a Service), and also provides useful
functions for using RBAC.
K2HR3 is a system that defines and controls HOW(policy Rule),
WHO(Role), WHAT(Resource), as RBAC. Users of K2HR3 can define
Role(WHO) groups to access freely defined Resource(WHAT) and control
access by policy Rule(HOW). By defining the information and assets
required for any system as a Resource(WHAT), K2HR3 system can give the
opportunity to provide access control in every situation.
K2HR3 provides +SERVICE feature, it strongly supports user system,
function and information linkage.

%prep
%autosetup -n %{name}-%{version}

%build
%run_autogen
%configure --disable-static 
make build

%install
%make_install
install -D -m 555 src/k2hr3                           %{buildroot}/usr/bin/k2hr3
install -D -m 444 src/libexec/common/CREDIT           %{buildroot}/usr/libexec/k2hr3/common/CREDIT
install -D -m 444 src/libexec/common/VERSION          %{buildroot}/usr/libexec/k2hr3/common/VERSION
install -D -m 444 src/libexec/common/k2hr3.config     %{buildroot}/usr/libexec/k2hr3/common/k2hr3.config
install -D -m 444 src/libexec/common/configuration.sh %{buildroot}/usr/libexec/k2hr3/common/configuration.sh
install -D -m 444 src/libexec/common/depends.sh       %{buildroot}/usr/libexec/k2hr3/common/depends.sh
install -D -m 444 src/libexec/common/help.sh          %{buildroot}/usr/libexec/k2hr3/common/help.sh
install -D -m 444 src/libexec/common/interactive.sh   %{buildroot}/usr/libexec/k2hr3/common/interactive.sh
install -D -m 444 src/libexec/common/jsonparser.sh    %{buildroot}/usr/libexec/k2hr3/common/jsonparser.sh
install -D -m 444 src/libexec/common/message.sh       %{buildroot}/usr/libexec/k2hr3/common/message.sh
install -D -m 444 src/libexec/common/modelist.sh      %{buildroot}/usr/libexec/k2hr3/common/modelist.sh
install -D -m 444 src/libexec/common/option.sh        %{buildroot}/usr/libexec/k2hr3/common/option.sh
install -D -m 444 src/libexec/common/request.sh       %{buildroot}/usr/libexec/k2hr3/common/request.sh
install -D -m 444 src/libexec/common/requestutil.sh   %{buildroot}/usr/libexec/k2hr3/common/requestutil.sh
install -D -m 444 src/libexec/common/strings.sh       %{buildroot}/usr/libexec/k2hr3/common/strings.sh
install -D -m 444 src/libexec/config/help.sh          %{buildroot}/usr/libexec/k2hr3/config/help.sh
install -D -m 444 src/libexec/config/summary.sh       %{buildroot}/usr/libexec/k2hr3/config/summary.sh
install -D -m 444 src/libexec/config/command.sh       %{buildroot}/usr/libexec/k2hr3/config/command.sh
install -D -m 444 src/libexec/acr/help.sh             %{buildroot}/usr/libexec/k2hr3/acr/help.sh
install -D -m 444 src/libexec/acr/summary.sh          %{buildroot}/usr/libexec/k2hr3/acr/summary.sh
install -D -m 444 src/libexec/acr/command.sh          %{buildroot}/usr/libexec/k2hr3/acr/command.sh
install -D -m 444 src/libexec/extdata/help.sh         %{buildroot}/usr/libexec/k2hr3/extdata/help.sh
install -D -m 444 src/libexec/extdata/summary.sh      %{buildroot}/usr/libexec/k2hr3/extdata/summary.sh
install -D -m 444 src/libexec/extdata/command.sh      %{buildroot}/usr/libexec/k2hr3/extdata/command.sh
install -D -m 444 src/libexec/list/help.sh            %{buildroot}/usr/libexec/k2hr3/list/help.sh
install -D -m 444 src/libexec/list/summary.sh         %{buildroot}/usr/libexec/k2hr3/list/summary.sh
install -D -m 444 src/libexec/list/command.sh         %{buildroot}/usr/libexec/k2hr3/list/command.sh
install -D -m 444 src/libexec/policy/help.sh          %{buildroot}/usr/libexec/k2hr3/policy/help.sh
install -D -m 444 src/libexec/policy/summary.sh       %{buildroot}/usr/libexec/k2hr3/policy/summary.sh
install -D -m 444 src/libexec/policy/command.sh       %{buildroot}/usr/libexec/k2hr3/policy/command.sh
install -D -m 444 src/libexec/resource/help.sh        %{buildroot}/usr/libexec/k2hr3/resource/help.sh
install -D -m 444 src/libexec/resource/summary.sh     %{buildroot}/usr/libexec/k2hr3/resource/summary.sh
install -D -m 444 src/libexec/resource/command.sh     %{buildroot}/usr/libexec/k2hr3/resource/command.sh
install -D -m 444 src/libexec/role/help.sh            %{buildroot}/usr/libexec/k2hr3/role/help.sh
install -D -m 444 src/libexec/role/summary.sh         %{buildroot}/usr/libexec/k2hr3/role/summary.sh
install -D -m 444 src/libexec/role/command.sh         %{buildroot}/usr/libexec/k2hr3/role/command.sh
install -D -m 444 src/libexec/service/help.sh         %{buildroot}/usr/libexec/k2hr3/service/help.sh
install -D -m 444 src/libexec/service/summary.sh      %{buildroot}/usr/libexec/k2hr3/service/summary.sh
install -D -m 444 src/libexec/service/command.sh      %{buildroot}/usr/libexec/k2hr3/service/command.sh
install -D -m 444 src/libexec/token/help.sh           %{buildroot}/usr/libexec/k2hr3/token/help.sh
install -D -m 444 src/libexec/token/summary.sh        %{buildroot}/usr/libexec/k2hr3/token/summary.sh
install -D -m 444 src/libexec/token/command.sh        %{buildroot}/usr/libexec/k2hr3/token/command.sh
install -D -m 444 src/libexec/token/library.sh        %{buildroot}/usr/libexec/k2hr3/token/library.sh
install -D -m 444 src/libexec/userdata/help.sh        %{buildroot}/usr/libexec/k2hr3/userdata/help.sh
install -D -m 444 src/libexec/userdata/summary.sh     %{buildroot}/usr/libexec/k2hr3/userdata/summary.sh
install -D -m 444 src/libexec/userdata/command.sh     %{buildroot}/usr/libexec/k2hr3/userdata/command.sh
install -D -m 444 src/libexec/version/help.sh         %{buildroot}/usr/libexec/k2hr3/version/help.sh
install -D -m 444 src/libexec/version/summary.sh      %{buildroot}/usr/libexec/k2hr3/version/summary.sh
install -D -m 444 src/libexec/version/command.sh      %{buildroot}/usr/libexec/k2hr3/version/command.sh
install -D -m 644 src/libexec/common/k2hr3.config     %{buildroot}/etc/antpickax/k2hr3.config

%if %{make_check}
%check
%{__make} check
%endif

%files
%license COPYING
%doc README AUTHORS ChangeLog
%{_mandir}/man1/*
/usr/bin/k2hr3
/usr/libexec/k2hr3/*
/etc/antpickax/*

%changelog
* Mon Nov 20 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.12-1
- Updated build_helper.sh for fixing a bug and installing ruby - #39

* Tue Oct 31 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.11
- Changed support OS (fedora and ubuntu) and updated tool - #37

* Fri Sep 01 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.10
- Updated tool scripts and support OSs - #35
- Fixed .gitignore to exclude APKBUILD.templ - #34

* Fri Jul 28 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.9
- Added tenant sub command for K2HR3 TENANT API - #32

* Mon Mar 06 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.8
- Updated building/packaging scripts - #30

* Thu Feb 16 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.7
- Added K2HR3CLI_GLOBAL_CONFIG_NOTUSE for plugin packages - #28

* Wed Feb 15 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.6
- Added alpine_build.sh to buildutils/Makefile.am - #26

* Tue Feb 14 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.5
- Changed CI OSs and added Alpine OS - #24
- Updated header and footer in comment lines - #23
- Updated issue/pullrequest templates and README.md - #22
- Added comments and updated .gitignore - #21
- Reviewed ShellCheck processing in Makefile.am - #20
- Reviewed ShellCheck processing and fixed bugs - #19
- Eliminated unnecessary copies in build_helper.sh - #18
- Updated ostypevars.sh for removing shellcheck pkg - #17
- Updated github actions process and support os, and fixed bugs - #16
- Updated debian_build.sh for grep parameter and updated configure.ac - #15
- Updated common build scripts - #14
- Updated buld tools(Makefile.am) - #13
- Separated the shellcheck process in the build process - #12
- Updated Antpickax common scripts and tools under the buildutils directory - #11
- Enabled external customization of variables in configure.ac - #10

* Fri Sep 10 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.4
- Supported OpenID Connect (OIDC) authorization for K2HR3 - #8

* Tue Apr 27 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.3
- Fixed a bug parsing for user home directory - #6

* Wed Apr 07 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.2
- Fixed an incorrect function name in debug message output - #4
- Fixed a bug that the passphrase would be saved without the option - #3

* Mon Mar 22 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.1
- Fixed README file - #1

* Mon Mar 22 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.0
- First version
